看可乐这些年的价格就知道国产饮料为什么死绝了 - 未名空间(mitbbs.com)
Description: 看可乐这些年的价格就知道国产饮料为什么死绝了
Keywords: 同主题阅读,看可乐这些年的价格就知道国产饮料为什么死绝了,乡里乡情,我爱北京天安门,

|  | mitbbs.com | 首页 | 分类讨论区 | 分类广告 | 移民专栏 | 新闻中心 | 精华区 | 未名博客 | 俱乐部 | 未名形象秀 | 未名黄页 |

首页 -分类讨论区 - 乡里乡情 - 我爱北京天安门版 - 同主题阅读文章 |

| 首页
| 分类广告
| 分类讨论区
| 移民专栏
| 新闻中心
| 军事新闻 国际新闻 体育新闻 娱乐新闻 科技新闻 财经新闻 美图频道 笑话频道
| 精华区
| 未名博客
| 俱乐部
| 未名形象秀
| 未名黄页
| 未名交友
| 未名人才

未名交友
[更多]
[更多]

看可乐这些年的价格就知道国产饮料为什么死绝了
[版面:我爱北京天安门][首篇作者：getout] , 2016年01月27日09:47:44
[分页:1 ]
| getout
进入未名形象秀
| 我的博客
| board=Beijing&u=getout
[回复] [回信给作者] [本篇全文] [本讨论区] [修改] [删除] [转寄] [转贴] [收藏] [举报] |  | [ 1 ]
发信人: getout (出去), 信区: Beijing 标 题: 看可乐这些年的价格就知道国产饮料为什么死绝了 发信站: BBS 未名空间站 (Wed Jan 27 09:48:05 2016, 美东) 稍微上了一点年纪的中国人，都听说过健力宝这个名字吧，其实健力宝现在还有的，只是不那么招风名存实亡了。当时健力宝号称民族品牌，中国当年普通人的工资不到一百块，健力宝就卖两块五一瓶。所以当时健力宝是贵族饮料，但因为被政府保护和民族情结，健力宝曾经有段时间活得很滋润。随着可乐和百事可乐等美国饮料巨无霸的进入，类似健力宝这类贵的离谱的饮料迅速失去市场，陷入困境。 和健力宝情况类似的，还有乐百氏、娃哈哈等，哇哈哈相对好一点，毕竟是矿泉水，与可乐没有直接冲突。这些年无论中国物价怎么飞速上涨，可乐的价格一直保持砸两块多到三块之间，越来越有比价效应。所以可乐和百事几乎完全占据了中国的碳酸饮料市场，记得娃哈哈当年还出过娃哈哈可乐，但马上失败了。 不只是饮料市场如此，快餐店也是，麦当劳、肯德基在刚进入中国市场，中国的快餐相比要便宜很多，但是十几年下来，肯德基、麦当劳的价格已经比国产快餐便宜了，所以国产国产也是死伤惨重。 这是真实的情况，那些叫嚣着中国将取代美国成为第一经济强国的愤愤们，观察一个国家经济的好玩，其实从身边小事就可以看得出来。 中国超越美国，做梦还是梦遗呀。 -- ※ 来源:·BBS 未名空间站 网址：mitbbs.com 移动：在应用商店搜索未名空间·[FROM: 10.]
| killerking
进入未名形象秀
| 我的博客
| board=Beijing&u=killerking
[回复] [回信给作者] [本篇全文] [本讨论区] [修改] [删除] [转寄] [转贴] [收藏] [举报] |  | [ 2 ]
发信人: killerking (杀手之王), 信区: Beijing 标 题: Re: 看可乐这些年的价格就知道国产饮料为什么死绝了 发信站: BBS 未名空间站 (Wed Jan 27 20:55:31 2016, 美东) 最起码有个梦做做 -- ※ 来源:·WWW 未名空间站 网址：mitbbs.com 移动：在应用商店搜索未名空间·[FROM: 174.]
| useCASE
进入未名形象秀
| 我的博客
| board=Beijing&u=useCASE
[回复] [回信给作者] [本篇全文] [本讨论区] [修改] [删除] [转寄] [转贴] [收藏] [举报] |  | [ 3 ]
发信人: useCASE (usecase), 信区: Beijing 标 题: Re: 看可乐这些年的价格就知道国产饮料为什么死绝了 发信站: BBS 未名空间站 (Sat Jan 30 02:50:09 2016, 美东) 中国市场上的可乐都是国产的 【 在 getout (出去) 的大作中提到: 】 : 稍微上了一点年纪的中国人，都听说过健力宝这个名字吧，其实健力宝现在还有的， 只是不那么招风名存实亡了。当时健力宝号称民族品牌，中国当年普通人的工资不到一 百块，健力宝就卖两块五一瓶。所以当时健力宝是贵族饮料，但因为被政府保护和民族 情结，健力宝曾经有段时间活得很滋润。随着可乐和百事可乐等美国饮料巨无霸的进入 ，类似健力宝这类贵的离谱的饮料迅速失去市场，陷入困境。 : 和健力宝情况类似的，还有乐百氏、娃哈哈等，哇哈哈相对好一点，毕竟是矿泉水， 与可乐没有直接冲突。这些年无论中国物价怎么飞速上涨，可乐的价格一直保持砸两块 多到三块之间，越来越有比价效应。所以可乐和百事几乎完全占据了中国的碳酸饮料市 场，记得娃哈哈当年还出过娃哈哈可乐，但马上失败了。 : 不只是饮料市场如此，快餐店也是，麦当劳、肯德基在刚进入中国市场，中国的快餐 相比要便宜很多，但是十几年下来，肯德基、麦当劳的价格已经比国产快餐便宜了，所 以国产国产也是死伤惨重。 : 这是真实的情况，那些叫嚣着中国将取代美国成为第一经济强国的愤愤们，观察一个 国家经济的好玩，其实从身边小事就可以看得出来。 : 中国超越美国，做梦还是梦遗呀。 -- ※ 来源:·WWW 未名空间站 网址：mitbbs.com 移动：在应用商店搜索未名空间·[FROM: 104.]
[分页:1 ]
[快速返回] [ 进入我爱北京天安门讨论区] [返回顶部]
回复文章
标题： |
内 容： |

将您的链接放在这儿
友情链接

Site Map - Contact Us - Terms and Conditions - Privacy Policy 版权所有，未名空间（mitbbs.com），since 1996